@@ -149,10 +149,16 @@ class PDFImageDraw(object):
             outline = kwargs.get('outline')
             self.rectangle(lines.outlinebox, fill='white', outline=outline)
 
+        rendered = False
         for string, xy in lines.lines:
             self.text(xy, string, font, **kwargs)
+            rendered = True
         self.canvas.restoreState()
 
+        if not rendered and font.size > 0:
+            font.size = int(font.size * 0.8)
+            self.textarea(box, string, font, **kwargs)
+
     def line(self, xy, **kwargs):
         self.set_stroke_color(kwargs.get('fill', 'none'))
         self.set_style(kwargs.get('style'), kwargs.get('thick'))
