@@ -15,7 +15,7 @@
 
 from blockdiag.noderenderer import NodeShape
 from blockdiag.noderenderer import install_renderer
-from blockdiag.utils import XY
+from blockdiag.utils import Box, XY
 
 
 class Diamond(NodeShape):
@@ -29,13 +29,12 @@ class Diamond(NodeShape):
                            XY(m.bottom.x, m.bottom.y + r),
                            XY(m.left.x - r, m.left.y),
                            XY(m.top.x, m.top.y - r)]
-        self.textbox = ((self.connectors[0].x + self.connectors[3].x) / 2,
-                        (self.connectors[0].y + self.connectors[3].y) / 2,
-                        (self.connectors[1].x + self.connectors[2].x) / 2,
-                        (self.connectors[1].y + self.connectors[2].y) / 2)
+        self.textbox = Box((self.connectors[0].x + self.connectors[3].x) / 2,
+                           (self.connectors[0].y + self.connectors[3].y) / 2,
+                           (self.connectors[1].x + self.connectors[2].x) / 2,
+                           (self.connectors[1].y + self.connectors[2].y) / 2)
 
     def render_shape(self, drawer, format, **kwargs):
-        outline = kwargs.get('outline')
         fill = kwargs.get('fill')
 
         # draw outline
@@ -47,11 +46,11 @@ class Diamond(NodeShape):
             drawer.polygon(self.connectors, fill=self.node.color,
                            outline=self.node.color)
             drawer.loadImage(self.node.background, self.textbox)
-            drawer.polygon(self.connectors, fill="none", outline=outline,
-                           style=self.node.style)
+            drawer.polygon(self.connectors, fill="none",
+                           outline=self.node.linecolor, style=self.node.style)
         else:
             drawer.polygon(self.connectors, fill=self.node.color,
-                           outline=outline, style=self.node.style)
+                           outline=self.node.linecolor, style=self.node.style)
 
 
 def setup(self):
