@@ -15,7 +15,7 @@
 
 from blockdiag.noderenderer import NodeShape
 from blockdiag.noderenderer import install_renderer
-from blockdiag.utils import XY
+from blockdiag.utils import Box, XY
 
 
 class LoopOut(NodeShape):
@@ -23,11 +23,10 @@ class LoopOut(NodeShape):
         super(LoopOut, self).__init__(node, metrics)
 
         m = self.metrics.cell(self.node)
-        xdiff = self.metrics.node_width / 4
         ydiff = self.metrics.node_height / 4
 
-        self.textbox = (m.topleft.x, m.topleft.y,
-                        m.bottomright.x, m.bottomright.y - ydiff)
+        self.textbox = Box(m.topleft.x, m.topleft.y,
+                           m.bottomright.x, m.bottomright.y - ydiff)
 
     def render_shape(self, drawer, format, **kwargs):
         fill = kwargs.get('fill')
