@@ -15,7 +15,7 @@
 
 from blockdiag.noderenderer import NodeShape
 from blockdiag.noderenderer import install_renderer
-from blockdiag.utils import XY
+from blockdiag.utils import Box, XY
 
 
 class Mail(NodeShape):
@@ -24,11 +24,10 @@ class Mail(NodeShape):
 
         m = self.metrics.cell(self.node)
         r = self.metrics.cellsize * 2
-        self.textbox = (m.topleft.x, m.topleft.y + r,
-                        m.bottomright.x, m.bottomright.y)
+        self.textbox = Box(m.topleft.x, m.topleft.y + r,
+                           m.bottomright.x, m.bottomright.y)
 
     def render_shape(self, drawer, format, **kwargs):
-        outline = kwargs.get('outline')
         fill = kwargs.get('fill')
 
         m = self.metrics.cell(self.node)
@@ -44,15 +43,17 @@ class Mail(NodeShape):
             drawer.rectangle(box, fill=self.node.color,
                              outline=self.node.color)
             drawer.loadImage(self.node.background, self.textbox)
-            drawer.rectangle(box, outline=outline, style=self.node.style)
+            drawer.rectangle(box, outline=self.node.linecolor,
+                             style=self.node.style)
         else:
-            drawer.rectangle(box, fill=self.node.color, outline=outline,
+            drawer.rectangle(box, fill=self.node.color,
+                             outline=self.node.linecolor,
                              style=self.node.style)
 
         # draw flap
         if not kwargs.get('shadow'):
             flap = [m.topleft, XY(m.top.x, m.top.y + r), m.topright]
-            drawer.line(flap, fill=outline, style=self.node.style)
+            drawer.line(flap, fill=self.node.linecolor, style=self.node.style)
 
 
 def setup(self):
