@@ -20,7 +20,6 @@ from blockdiag.utils import XY
 
 class Note(NodeShape):
     def render_shape(self, drawer, format, **kwargs):
-        outline = kwargs.get('outline')
         fill = kwargs.get('fill')
 
         m = self.metrics.cell(self.node)
@@ -40,18 +39,19 @@ class Note(NodeShape):
             drawer.polygon(note, fill=self.node.color,
                            outline=self.node.color)
             drawer.loadImage(self.node.background, box)
-            drawer.polygon(note, fill="none", outline=outline,
-                           style=self.node.style)
+            drawer.polygon(note, fill="none",
+                           outline=self.node.linecolor, style=self.node.style)
         else:
-            drawer.polygon(note, fill=self.node.color, outline=outline,
-                           style=self.node.style)
+            drawer.polygon(note, fill=self.node.color,
+                           outline=self.node.linecolor, style=self.node.style)
 
         # draw folded
         if not kwargs.get('shadow'):
             folded = [XY(tr.x - r, tr.y),
                       XY(tr.x - r, tr.y + r),
                       XY(tr.x, tr.y + r)]
-            drawer.line(folded, fill=outline, style=self.node.style)
+            drawer.line(folded, fill=self.node.linecolor,
+                        style=self.node.style)
 
 
 def setup(self):
