@@ -46,12 +46,18 @@ def test_edge_attribute():
         if edge.node1.id == 'D':
             assert edge.dir == 'none'
             assert edge.color == (0, 0, 0)
+            assert edge.thick == None
+        elif edge.node1.id == 'F':
+            assert edge.dir == 'forward'
+            assert edge.color == (0, 0, 0)
+            assert edge.thick == 3
         else:
             assert edge.dir == 'forward'
             assert edge.color == (255, 0, 0)  # red
+            assert edge.thick == None
 
     positions = {'A': (0, 0), 'B': (1, 0), 'C': (2, 0),
-                 'D': (0, 1), 'E': (1, 1)}
+                 'D': (0, 1), 'E': (1, 1), 'F': (0, 2), 'G': (1, 2)}
     __validate_node_attributes('edge_attribute.diag', xy=positions)
 
 
