@@ -3,7 +3,7 @@ import re
 from StringIO import StringIO
 from nose.tools import eq_
 from blockdiag.builder import *
-from blockdiag.diagparser import parse_string
+from blockdiag.parser import parse_string
 
 
 def argv_wrapper(func, argv=[]):
@@ -38,6 +38,24 @@ def stderr_wrapper(func):
     return wrap
 
 
+def assertRaises(exc):
+    def decorator(func):
+        def fn(self, *args, **kwargs):
+            try:
+                func(self, *args, **kwargs)
+            except exc:
+                pass
+            else:
+                msg = '%s does not raise exceptions: %s' % \
+                      (func.__name__, str(exc))
+                self.fail(msg)
+
+        fn.__name__ = func.__name__
+        return fn
+
+    return decorator
+
+
 def __build_diagram(filename):
     import os
     testdir = os.path.dirname(__file__)
