@@ -18,13 +18,12 @@ from TextFolder import TextFolder
 
 
 class PDFTextFolder(TextFolder):
-    def __init__(self, box, string, **kwargs):
+    def __init__(self, box, string, font, **kwargs):
         self.canvas = kwargs.get('canvas')
-        self.font = kwargs.get('font')
-        self.fontsize = kwargs.get('fontsize', 11)
+        self.font = font
 
-        TextFolder.__init__(self, box, string, **kwargs)
+        TextFolder.__init__(self, box, string, font, **kwargs)
 
     def textsize(self, string):
-        width = self.canvas.stringWidth(string, self.font, self.fontsize)
-        return (int(math.ceil(width)), self.fontsize)
+        width = self.canvas.stringWidth(string, self.font.path, self.font.size)
+        return (int(math.ceil(width)), self.font.size)
