@@ -6,7 +6,7 @@ import urlparse
 def isurl(url):
     o = urlparse.urlparse(url)
     accpetable = ["http", "https"]
-    if o.scheme in accpetable:
+    if o[0] in accpetable:
         return True
     else:
         return False
