@@ -13,7 +13,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from blockdiag import command, diagparser, builder, DiagramDraw
+from blockdiag import command, parser, builder, drawer
+from blockdiag import parser as diagparser
+from blockdiag import drawer as DiagramDraw
 from blockdiag.utils import collections
 from blockdiag.utils.fontmap import FontMap
 from blockdiag.utils.rst.directives import blockdiag, BlockdiagDirective
